@@ -10,21 +10,22 @@
 ###############################################################################
 
 __all__ = [
+    "get_api_token",
+    "wipe_token_cache",
     "hacks",
     "render_yaml",
     "parse_yaml",
     "validate_yaml",
     "lint_all",
     "validators",
-    "get_sso_token",
     "write_jsroot_compression_options",
 ]
 
 from os.path import join
 
 from . import hacks, validators
+from .auth import get_api_token, wipe_token_cache
 from .linting import lint_all
-from .new_cern_sso import get_sso_token
 from .parsing import parse_yaml, render_yaml, validate_yaml
 
 
