@@ -27,6 +27,7 @@ class CheckResult:
 
     check_type: str
     passed: bool
+    can_combine: bool
     messages: List[str] = field(default_factory=list)
     tree_data: Dict[str, Dict] = field(default_factory=dict)
 
@@ -122,7 +123,7 @@ def num_entries(
         A CheckResult object, which for each tree contains tree_data key/values:
             num_entries: The total number of events in the TTree
     """
-    result = CheckResult("num_entries", False)
+    result = CheckResult("num_entries", False, True)
     for filepath in filepath_list:
         trees_opened = []
         with uproot.open(filepath) as f:
@@ -153,6 +154,7 @@ def num_entries(
     # If no matches were found the check should be marked as failed
     if len(result.tree_data) == 0:
         result.passed = False
+        result.can_combine = False
         result.messages += [f"No TTree objects found that match {tree_pattern}"]
 
     return result
@@ -199,7 +201,7 @@ def range_check(
             num_entries_in_mean_window (float): The number of events falling in the exp_mean +- exp_std region (with
                 blind ranges applied)
     """
-    result = CheckResult("range", True)
+    result = CheckResult("range", True, True)
     bin_centers = None
 
     for filepath in filepath_list:
@@ -236,6 +238,7 @@ def range_check(
                 except uproot.exceptions.KeyInFileError as e:
                     result.messages += [f"Missing branch in {key!r} with {e!r}"]
                     result.passed = False
+                    result.can_combine = False
                     continue
 
                 # Evaluate expression & apply limits
@@ -275,6 +278,7 @@ def range_check(
     # If no matches are found the check should be marked as failed, and can return early
     if len(result.tree_data) == 0:
         result.passed = False
+        result.can_combine = False
         result.messages += [f"No TTree objects found that match {tree_pattern}"]
         return result
 
@@ -285,6 +289,8 @@ def range_check(
             h = result.tree_data[key]["histograms"][0]
 
             # Require at least one event
+            # However, even if the histogram is empty, we want to be able to combine
+            # the result later (so "can_combine" flag is left "True")
             if h.sum() == 0:
                 result.passed = False
                 result.messages += [f"No events found in range for Tree {key}"]
@@ -359,7 +365,7 @@ def range_check_nd(
             histograms (list[Hist]): A list of filled histograms of the quantities defined by the expression parameters
             num_entries (float): The total number of entries in the histogram (with blind ranges applied)
     """
-    result = CheckResult("range_nd", True)
+    result = CheckResult("range_nd", True, True)
 
     # Check if the number of variables matches expectations
     length_expr = len(expressions)
@@ -367,12 +373,14 @@ def range_check_nd(
     if length_expr != 2 and length_expr != 3:
         result.messages += ["Expected two or three variables."]
         result.passed = False
+        result.can_combine = False
         return result
     if length_expr != length_limits:
         result.messages += [
             "For each variable, a corresponding range should be defined."
         ]
         result.passed = False
+        result.can_combine = False
         return result
 
     for filepath in filepath_list:
@@ -450,6 +458,7 @@ def range_check_nd(
                 except uproot.exceptions.KeyInFileError as e:
                     result.messages += [f"Missing branch in {key!r} with {e!r}"]
                     result.passed = False
+                    result.can_combine = False
                     continue
 
                 # Apply blinding
@@ -513,6 +522,7 @@ def range_check_nd(
     # If no matches are found the check should be marked as failed, and can return early
     if len(result.tree_data) == 0:
         result.passed = False
+        result.can_combine = False
         result.messages += [f"No TTree objects found that match {tree_pattern}"]
         return result
 
@@ -560,7 +570,7 @@ def num_entries_per_invpb(
             lumi_invpb (float): The total luminosity, in inverse picobarns
             num_entries_per_invpb (float): The total number of events divided by the total luminosity
     """
-    result = CheckResult("num_entries_per_invpb", True)
+    result = CheckResult("num_entries_per_invpb", True, True)
 
     lumi = 0
     for filepath in filepath_list:
@@ -598,11 +608,13 @@ def num_entries_per_invpb(
                             f"Missing luminosity branch in {key!r} with error {e!r}"
                         ]
                         result.passed = False
+                        result.can_combine = False
                         break
 
                     err_lumi_quad_sum = math.sqrt(numpy.sum(err_lumi_arr**2))
                     if err_lumi_quad_sum / numpy.sum(lumi_arr) >= 1:
                         result.passed = False
+                        result.can_combine = False
                         result.messages += [
                             "Luminosity information is not reliable: 100% or greater relative uncertainty"
                         ]
@@ -613,6 +625,7 @@ def num_entries_per_invpb(
     # If no matches are found the check should be marked as failed, and can return early
     if len(result.tree_data) == 0:
         result.passed = False
+        result.can_combine = False
         result.messages += [f"No TTree objects found that match {tree_pattern}"]
         return result
 
@@ -620,6 +633,7 @@ def num_entries_per_invpb(
         for key in result.tree_data:
             if lumi == 0:
                 result.passed = False
+                result.can_combine = False
                 result.messages += [
                     "Failed to get luminosity information (total luminosity = 0)"
                 ]
@@ -683,7 +697,7 @@ def range_check_bkg_subtracted(
                 Index 2: Events in the background window
                 Index 3: The background-subtracted result
     """
-    result = CheckResult("range_bkg_subtracted", True)
+    result = CheckResult("range_bkg_subtracted", True, True)
 
     for filepath in filepath_list:
         trees_opened = []
@@ -697,7 +711,7 @@ def range_check_bkg_subtracted(
                     continue
                 trees_opened.append(key)
 
-                # Caluclate the min and max values of each of the two background regions.
+                # Calculate the min and max values of each of the two background regions.
                 # By construction, the two intervals have the same length
                 background_range_low = {
                     "min": mean_sig - background_shift - background_window,
@@ -707,7 +721,7 @@ def range_check_bkg_subtracted(
                     "min": mean_sig + background_shift,
                     "max": mean_sig + background_shift + background_window,
                 }
-                # Caluclate the min and max values of each of the signal region
+                # Calculate the min and max values of each of the signal region
                 signal_range = {
                     "min": mean_sig - signal_window / 2.0,
                     "max": mean_sig + signal_window / 2.0,
@@ -724,7 +738,11 @@ def range_check_bkg_subtracted(
                         name=expr_for_subtraction,
                     )
                     result.tree_data[key]["histograms"] = [
-                        Hist(axis0, name=f"{key} {expression}")
+                        Hist(
+                            axis0,
+                            name=f"{key} {expression}",
+                            storage=hist.storage.Weight(),
+                        )
                     ]
                     # Add ranges to histogram metadata. Signal and background regions can be then highlighted in the final plot.
                     result.tree_data[key]["histograms"][0].metadata = [
@@ -741,10 +759,25 @@ def range_check_bkg_subtracted(
                         n_bins, limits["min"], limits["max"], name=expression
                     )
                     result.tree_data[key]["histograms"].append(
-                        Hist(axis1, name=f"{key} {expression} signal")
+                        Hist(
+                            axis1,
+                            name=f"{key} {expression} signal",
+                            storage=hist.storage.Weight(),
+                        )
                     )
                     result.tree_data[key]["histograms"].append(
-                        Hist(axis1, name=f"{key} {expression} background")
+                        Hist(
+                            axis1,
+                            name=f"{key} {expression} background",
+                            storage=hist.storage.Weight(),
+                        )
+                    )
+                    result.tree_data[key]["histograms"].append(
+                        Hist(
+                            axis1,
+                            name=f"{key} {expression} signal after bkg subtraction",
+                            storage=hist.storage.Weight(),
+                        )
                     )
 
                 values_obj = {}
@@ -756,6 +789,7 @@ def range_check_bkg_subtracted(
                 except uproot.exceptions.KeyInFileError as e:
                     result.messages += [f"Missing branch in {key!r} with {e!r}"]
                     result.passed = False
+                    result.can_combine = False
                     continue
 
                 # Fill control variable histogram
@@ -832,6 +866,7 @@ def range_check_bkg_subtracted(
     # If no matches are found the check should be marked as failed, and can return early
     if len(result.tree_data) == 0:
         result.passed = False
+        result.can_combine = False
         result.messages += [f"No TTree objects found that match {tree_pattern}"]
         return result
 
@@ -839,8 +874,8 @@ def range_check_bkg_subtracted(
         for key in result.tree_data:
 
             # Require events in both signal and background histograms
-            if (result.tree_data[key]["histograms"][1].sum() == 0) or (
-                result.tree_data[key]["histograms"][2].sum() == 0
+            if (result.tree_data[key]["histograms"][1].view().value.sum() == 0) or (
+                result.tree_data[key]["histograms"][2].view().value.sum() == 0
             ):
                 result.passed = False
                 result.messages += [
@@ -856,7 +891,7 @@ def range_check_bkg_subtracted(
                 result.tree_data[key]["histograms"][1]
                 + (-1 * alpha) * result.tree_data[key]["histograms"][2]
             )
-            result.tree_data[key]["histograms"] += [hsub]
+            result.tree_data[key]["histograms"][3] = hsub
 
             result.messages += [
                 f"Background subtraction performed successfully for Tree {key}"
@@ -882,7 +917,7 @@ def branches_exist(
     Returns:
         A CheckResult object, which for each tree contains no tree_data key/values (an empty dict)
     """
-    result = CheckResult("branches_exist", True)
+    result = CheckResult("branches_exist", True, True)
     for filepath in filepath_list:
         trees_opened = []
         with uproot.open(filepath) as f:
@@ -903,6 +938,7 @@ def branches_exist(
                 if not set(branches).issubset(obj.keys()):
                     missing_branches = list(set(branches) - set(obj.keys()))
                     result.passed = False
+                    result.can_combine = False
                     result.messages += [
                         f"Required branches not found in Tree {key}: {missing_branches}"
                     ]
@@ -910,6 +946,7 @@ def branches_exist(
     # If no matches are found the check should be marked as failed, and can return early
     if len(result.tree_data) == 0:
         result.passed = False
+        result.can_combine = False
         result.messages += [f"No TTree objects found that match {tree_pattern}"]
         return result
 
