@@ -36,17 +36,23 @@ RE_CONDDB_TAG = r"^.{1,50}$"
 RE_COMMENT = r"(.{1,5000})"
 DQ_FLAGS_SCHEMA = Seq(Enum(["BAD", "OK", "EXPRESS_OK", "UNCHECKED"]))
 
+LEGACY_OPTIONS = {
+    Optional("command"): Seq(Str()),
+    "files": Seq(Regex(RE_OPTIONS_FN)),
+}
 LBEXEC_OPTIONS = {
     "entrypoint": Regex(r".+:.+"),
     Optional("extra_options"): MapPattern(Str(), Any()),
-    Optional("extra_args"): Seq(str),
+    Optional("extra_args"): Seq(Str()),
 }
 
 BASE_JOB_SCHEMA = {
     "application": Regex(RE_APPLICATION),
     "input": MapPattern(Str(), Any()),
     "output": Regex(RE_OUTPUT_FILE_TYPE) | Seq(Regex(RE_OUTPUT_FILE_TYPE)),
-    "options": Regex(RE_OPTIONS_FN) | Seq(Regex(RE_OPTIONS_FN)) | Map(LBEXEC_OPTIONS),
+    "options": Regex(RE_OPTIONS_FN)
+    | Seq(Regex(RE_OPTIONS_FN))
+    | MapPattern(Str(), Any()),
     "wg": Enum(config.known_working_groups),
     "inform": Regex(RE_INFORM) | Seq(Regex(RE_INFORM)),
     # Automatic configuration
@@ -455,6 +461,11 @@ def parse_yaml(rendered_yaml):
                 )
                 % (k, set(INPUT_SCHEMAS))
             )
+        if isinstance(data.data[k]["options"], dict):
+            if "files" in data.data[k]["options"]:
+                data[k]["options"].revalidate(Map(LEGACY_OPTIONS))
+            else:
+                data[k]["options"].revalidate(Map(LBEXEC_OPTIONS))
 
         # move contents of extra_checks to checks
         data_dict = data.data
@@ -508,12 +519,46 @@ def _check_name_magnet_polarity(bk_query, job_name):
     if match and match.groups()[1] == bad_pol[0]:
         raise ValueError(
             f"Found 'm{bad_pol[0]}' in job name {job_name!r} with"
-            f"'mag{good_pol}' input ({bk_query!r}). "
+            f" 'mag{good_pol}' input ({bk_query!r}). "
             "Has the wrong magnet polarity been used?"
         )
     return []
 
 
+def _check_job_chain_name_polarity(job_name: str, input_job_name: str) -> list:
+    mags = ["mag", "m"]
+    down = ["down", "d"]
+    up = ["up", "u"]
+    for i, pattern in enumerate(
+        [
+            r"([^a-z0-9]|\b)mag(up|down)([^a-z0-9]|\b)",
+            r"([^a-z0-9]|\b)m(u|d)([^a-z0-9]|\b)",
+        ]
+    ):
+        matches = [
+            re.search(pattern, name, re.IGNORECASE)
+            for name in [job_name, input_job_name]
+        ]
+        if matches[1]:
+            groups = [group for group in matches[1].groups() if group != "_"]
+            good_pol = groups[0].lower()
+            bad_pol = {down[i]: up[i], up[i]: down[i]}[good_pol]
+            if f"{mags[i]}{bad_pol}" in job_name.lower():
+                raise ValueError(
+                    f"Found '{mags[i]}{bad_pol}' in job name {job_name!r} with"
+                    f" '{mags[i]}{good_pol}' input ({input_job_name!r}). "
+                    "Has the wrong magnet polarity been used?"
+                )
+            break
+    else:
+        return [
+            f"Failed to find magnet polarity in {input_job_name}, "
+            "cannot determine if polarities are matched throughout the job chain"
+        ]
+
+    return []
+
+
 def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
     """Validate YAML configuration.
 
@@ -548,11 +593,14 @@ def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
             bk_query_to_job[job_data["input"]["bk_query"].lower()].add(job_name.lower())
 
         elif "job_name" in job_data["input"]:
-            # Ensire that the job name and output filetype are unambiguously defined
+            # Ensure that the job name and output filetype are unambiguously defined
             if job_data["input"]["job_name"] not in jobs_data:
                 raise ValueError(
                     f"Unrecognised job name in input: {job_data['input']['job_name']}"
                 )
+            warnings.extend(
+                _check_job_chain_name_polarity(job_name, job_data["input"]["job_name"])
+            )
             input_job_data = jobs_data[job_data["input"]["job_name"]]
             input_filetype = job_data["input"].get("filetype", "").upper()
             if len(input_job_data["output"]) == 1:
@@ -563,7 +611,7 @@ def validate_yaml(jobs_data, checks_data, repo_root, prod_name):
                     )
             elif input_filetype == "":
                 raise ValueError(
-                    f"{job_name} gets it's input from a job with multiple outputs. "
+                    f"{job_name} gets its input from a job with multiple outputs. "
                     "The 'filetype' key must be specified in the 'input' section."
                 )
             elif input_filetype.upper() not in input_job_data["output"]:
@@ -642,8 +690,10 @@ def _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data):
 
     # Normalise the options filenames if we're using a non-PyConf application
     if isinstance(job_data["options"], list):
+        job_data["options"] = {"files": job_data["options"]}
+    if "files" in job_data["options"]:
         normalised_options = []
-        for fn in job_data["options"]:
+        for fn in job_data["options"]["files"]:
             if fn.startswith("$"):
                 normalised_options.append(fn)
                 continue
@@ -659,7 +709,7 @@ def _validate_job_data(repo_root, prod_name, job_name, job_data, checks_data):
             normalised_options.append(
                 join("$ANALYSIS_PRODUCTIONS_BASE", prod_name, fn_normed)
             )
-        job_data["options"] = normalised_options
+        job_data["options"]["files"] = normalised_options
 
     # Validate the check names
     # All checks listed for jobs should match a check defined in checks_data
