@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2020 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2020-2022 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -27,7 +27,7 @@ from .logs import count_log_messages, explain_log
 
 
 def match_output_filenames(filenames, output_filetypes, application_name, step_index):
-    """File the XML, log and output filenames from a test job
+    """File the XML, log and output filenames from a test job.
 
     Parameters
     ----------
@@ -95,17 +95,16 @@ def match_output_filenames(filenames, output_filetypes, application_name, step_i
 
 
 def status_from_xml_summary(fp):
-    """Check is the job succeeded using the XML summary file
+    """Check if the job succeeded using the XML summary file.
 
-    Parameters
-    ----------
-    fp : file-like
-        File pointer of the XML summary
+    Args:
+        fp (file-like): _description_
 
-    Returns
-    -------
-    passed : :obj:`bool`
-        True to the XML summary reports the job as passed
+    Raises:
+        NotImplementedError: _description_
+
+    Returns:
+        bool: whether the XML summary reports the job as passed
     """
     try:
         xml_summary = etree.parse(fp, base_url="LbAnalysisProductions/data/xml")
