@@ -102,7 +102,7 @@ def test_good_output_filetype_scalar(value, expected):
     assert jobs_data["job_1"]["input"] == {
         "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
     }
-    assert jobs_data["job_1"]["options"] == ["$VAR/a.py"]
+    assert jobs_data["job_1"]["options"] == {"files": ["$VAR/a.py"]}
     assert jobs_data["job_1"]["wg"] == "Charm"
     assert jobs_data["job_1"]["automatically_configure"] is False
     assert jobs_data["job_1"]["turbo"] is False
@@ -557,6 +557,45 @@ def test_good_automatically_configure_defaults_overrides():
     assert checks_data == {}
 
 
+def test_good_gaudipython():
+    rendered_yaml = dedent(
+        """\
+    job_1:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.ROOT
+        options:
+            command:
+                - python
+            files:
+                - options.py
+        wg: Charm
+        inform: a.b@c.d
+        priority: 1a
+        completion_percentage: 99.5
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    assert len(jobs_data) == 1
+    assert jobs_data["job_1"]["application"] == "DaVinci/v45r3"
+    assert jobs_data["job_1"]["input"] == {
+        "bk_query": "/MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST"
+    }
+    assert jobs_data["job_1"]["output"] == "FILETYPE.ROOT"
+    assert jobs_data["job_1"]["options"] == {
+        "command": ["python"],
+        "files": ["options.py"],
+    }
+    assert jobs_data["job_1"]["wg"] == "Charm"
+    assert jobs_data["job_1"]["automatically_configure"] is False
+    assert jobs_data["job_1"]["turbo"] is False
+    assert jobs_data["job_1"]["inform"] == "a.b@c.d"
+    assert jobs_data["job_1"]["priority"] == "1a"
+    assert jobs_data["job_1"]["completion_percentage"] == 99.5
+    assert checks_data == {}
+
+
 def test_good_with_checks_no_defaults():
     rendered_yaml = dedent(
         """\
@@ -1283,3 +1322,123 @@ def test_duplicate_bk_query():
         "/mc/2018/beam6500gev-2018-magdown/sim09g/trig0x617d18a4/reco18/24142001/allstreams.dst"
         in warnings
     )
+
+
+def test_good_job_chain_polarity():
+    rendered_yaml = dedent(
+        """\
+    job_1_MagDown:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.DST
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_1_MagUp:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.DST
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_2_MagDown:
+        application: DaVinci/v45r3
+        input:
+            job_name: job_1_MagDown
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/b.py
+        wg: Charm
+        inform: a.b@c.d
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+    assert warnings == []
+
+
+def test_bad_job_chain_polarity():
+    rendered_yaml = dedent(
+        """\
+    job_1_MagDown:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.DST
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_1_MagUp:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.DST
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_2_MagDown:
+        application: DaVinci/v45r3
+        input:
+            job_name: job_1_MagUp
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/b.py
+        wg: Charm
+        inform: a.b@c.d
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    with pytest.raises(ValueError):
+        LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+
+
+def test_missing_job_chain_polarity():
+    rendered_yaml = dedent(
+        """\
+    job_1_x:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagDown/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.DST
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_1_y:
+        application: DaVinci/v45r3
+        input:
+            bk_query: /MC/2018/Beam6500GeV-2018-MagUp/Sim09g/Trig0x617d18a4/Reco18/24142001/ALLSTREAMS.DST
+        output: FILETYPE.DST
+        options:
+            - $VAR/a.py
+        wg: Charm
+        inform: a.b@c.d
+
+    job_2:
+        application: DaVinci/v45r3
+        input:
+            job_name: job_1_x
+        output: FILETYPE.ROOT
+        options:
+            - $VAR/b.py
+        wg: Charm
+        inform: a.b@c.d
+    """
+    )
+    jobs_data, checks_data = LbAPCommon.parse_yaml(rendered_yaml)
+    warnings = LbAPCommon.validate_yaml(jobs_data, checks_data, "a", "b")
+    assert (
+        "Failed to find magnet polarity in job_1_x, cannot determine if polarities are matched throughout the job chain"
+        in warnings
+    )
